
--[[                                     CurrencyMonitor

This program watches a player's justice points, valor points, conquest points, and honor points
and flashes an alert when any of them exceeds a predetermined threshold. Change the value on 
line 70 to your desired threshold. CurrencyMonitor is meant to be super simple and configurable
only from within this file, meaning you won't find any slash commands or in-game configuration.

                 *** CurrencyMonitor is Copyright 2011 by Phael of Hydraxis ***

Please do not distribute altered copies of this add-on because it can make maintaining it a 
nightmare. If you want to see a feature built into it, please add a comment on the official 
download pages on curse.com and wowinterface.com.

For now, I will take bug reports and feature requests directly in the comments sections of the 
official release channels. Until such a time that I believe I need a ticket tracking system (which
hopefully never happens), I will simply answer bug reports/feature requests in comments sections.

---------------
Version History
---------------

12/2/2011 - V.0.1(BETA) (Initial release)
		  - V.1.0       Now firing on the correct event  
12/5/2011 - V.1.1       Removed BG spamminess through smart points announcement
		  
-----
To-Do
-----

Pick nose, wipe under the table.

--- Credits ---

Credit goes to Wowhead user eidyia for the idea and additional input that helped hone this add-on's
functionality. Specifically, thank eidyia for the version 1.1 removal of BG spam!

--]]

-- A few tables to hold our important stuff
currencies = {
	"395", -- Justice points
	"396", -- Valor points
	"392", -- Honor points
	"390"  -- Conquest points
}

pveCurrency = {
	"Justice Points",
	"Valor Points"
}

pvpCurrency = {
	"Honor Points",
	"Conquest Points"
}

--[[
	Line 70 below holds the threshold at which you want CurrencyMonitor to alert you. After gaining
	a currency, for example Justice Points, if you have more than the value below, this add-on will
	alert you with a raid warning. If you want the raid warning sound, simply remove the --	from the
	beginning of lines 104 and 111.

	New to version 1.1: The variable minToWarn (line 71) represents the individual amount for which 
	CM will warn the user. For example, by default honorable kills worth 7 honor will not fire the
	warning	because they are less than 50 (the default value for minToWarn). If you set minToWarn to
	zero, every honor gain, even 1 point, will spam you.
--]]

local maxAmount = 3000
local minToWarn = 50
-- Know what you're doing before you edit anything below this line. --

local currencyType = ""

-- Register event. Makes the CurrencyMonitor_OnEvent() function fire when this event occurs.
function CurrencyMonitor_OnLoad()
	CurrencyMonitorFrame:RegisterEvent("CHAT_MSG_CURRENCY")
end

local function getPvECurrencies()
	
	currentAmount = {}
	
	for i = 1, 2 do
		local _, amountNow = GetCurrencyInfo(currencies[i])
		table.insert(currentAmount, amountNow)
	end
end

local function getPvPCurrencies()

	currentAmount = {}

	for i = 3, 4 do
		local _, amountNow = GetCurrencyInfo(currencies[i])
		table.insert(currentAmount, amountNow)
	end
end

local function printOutput(currencyType)
		
	if currencyType == "pvp" then
		--PlaySoundFile("Sound\\Interface\\RaidWarning.wav")
		for i = 1, 2 do
			RaidNotice_AddMessage(RaidWarningFrame, "You have " .. currentAmount[i] .. " " .. pvpCurrency[i] .. "!", ChatTypeInfo["RAID_WARNING"])
		end
	end
	
	if currencyType == "pve" then
		--PlaySoundFile("Sound\\Interface\\RaidWarning.wav")
		for i = 1, 2 do
			RaidNotice_AddMessage(RaidWarningFrame, "You have " .. currentAmount[i] .. " " .. pveCurrency[i] .. "!", ChatTypeInfo["RAID_WARNING"])
		end
	end
end

function CurrencyMonitor_OnEvent(event, arg1)

	local trigger = string.match(arg1, '%d+', -4)
	local _, zone = IsInInstance()
	
	if zone == "raid" or zone == "party" then
		currencyType = "pve"
		getPvECurrencies()
	else
		currencyType = "pvp"
		getPvPCurrencies()
	end
	
	if tonumber(trigger) > tonumber(minToWarn) then
		if currentAmount[1] > maxAmount or currentAmount[2] > maxAmount then
			printOutput(currencyType)
		end
	end
end